@@ -201,7 +201,7 @@ extern ulonglong strtoull(const char *str, char **ptr, int base);
 
 #ifdef __cplusplus
 #include <type_traits>
-template<typename T> inline const char *_swl_check(T s)
+template<typename T> inline constexpr const char *_swl_check(T s)
 {
   static_assert(std::is_same<T, const char (&)[sizeof(T)]>::value
              || std::is_same<T, const char [sizeof(T)]>::value,
